bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 30. Aventiure
___________________________________________________
| ### <Der> tach der hete nv ende vnd nahet in div naht ### di wegmveden rechen ir sorge si an vaht ### wanne si solden rwen vnd an ir bette gan ### daz beredete Hagene ez wart in shiere chvnt getan ### Gventher sprach ce dem wirte got laz ivch wol geleben ### wir wellen varn slaffen ir svlt vns vrlovb geben ### swenne ir daz gebietet so chom wir morgen frvo ### er shiet von sinen gesten vil harte vroelichen do
###### 1817 | ### Dringen allenthalben di geste man do sach ### Volker der chvene zv den Hivnen sprach ### wi getvrret ir den rechen fver di fveze gan ### vnde welt irs ivch niht miden so wirt iv leide getan
| ### So slah ich etelichem so swæren gegen slalch ### hat er getriwer iemen der ez beweinen mach ### wan wichet ir vns rechen ia dvnchet ez mich gvt ### ez heizent allez degene vnde sint geliche niht gemvt
###### 1819 | ### Do der videlære so zornechlichen sprach ### Hagen der chvene hinder sich do sach ### er sprach iv ratet rehte der chvene spileman ### ir Criemhilde helde ir svlt cen herbergen gan
###### 1820 | ### Des ir da habt willen ich wæn iz iemen [382a] tv ### welt <ir> ihtes beginnen so chvmet vns morgen frv ### vnde lat vns ellende hint haben gemach ### ia wæne ez von helden mit solhem willen ie geschach
| ### Do brahte man di geste in einen witen sal ### den fvnden si berihtet den recken vber al ### mit vil richen betten lanch vnd breit ### in riet div vrowe Crimhilt div aller grozesten leit
###### 1822 | ### Vil manigen kolter spæhe von Arraz man da sach ### der vil liehten pfellel vnd manech pette dach ### von arabisschen siden di beste mohten sin ### dar vffe lagen listen di gaben herlichen schin
###### 1823 | ### Div dechlachen hermin vil manegiv man da sach ### vnd von swarcem zoble dar vnder si ir gemach ### des nahtes shaffen solden vnz an den liehten tach ### ein kvnech mit sinem gesinde ni so herlich gelach
| ### Owe der nahtselde sprach Giselher daz chint ### vnd owe miner frivnde di mit vns chomen sint ### swi et ez vns min swester so gvetliche erbot ### ich fvrhte daz wir mvezen von ir schvlden ligen tot
###### 1825 | ### Nv lazet iwer sorgen sprach Hagen der degen ### ich wil noch hinte selbe der shiltwahte pflegen ### ich trwe vns wol behveten vnz chomet der tach ### des sit gar an angest so genese swer der mach
###### 1826 | ### Do nigen si im alle vnde sagten im des danch ### si giengen zv den betten div wile was niht lanch ### daz sich geleget heten di wætlichen man ### Hagen der chvene helt sich waffen began
| ### Do sprach der videlære Wolker der degen ### versmahet ez iv niht Hagene so wolde ich mit iv pflegen ### der shiltwahte hinte vnz morgen frvo ### der helt vil minnechliche danchet Volkere do
###### 1828 | ### Nv lon iv got von himele vil lieber Volker ### zallen minen sorgen son gert ich niemens mer ### niwan ivch aleine swa ich hete not ### ich sol ez wol verdienen mich enwendes der tot
###### 1829 | ### Do garten si sich beide in liehtez ir gewant ### do nam ir ietwedere den schilt an sine hant ### vnd giengen [382b] vz dem hvse fver di tver stan ### do pflagen si der geste daz was mit triwen getan
| ### Volker der snelle zv des sales want ### sinen shilt den gvten leit er von der hant ### do gi er hin widere di videl er genam ### do diente er sinen frivnden als ez dem helde gezam
###### 1831 | ### Vnder di tver des hvses saz er fver den stein ### chvener videlære der wart ni dehein ### do im der seiten doenen so svezechlich erclanch ### di stolzen ellenden sagtens Volkeren danch
###### 1832 | ### Do chlvngen sine seiten daz allez daz hvs erdoz ### sin ellen zv der fvege div beidiv waren groz ### ie <svezer> vnd svezer er videln began ### do entswebte er an <den> betten vil manegen sorgenden man
| ### Do si entslaffen waren vnd er daz ervant ### do nam der degen widere den schilt an di hant ### vnd gie zv dem gademe fver den tvrn stan ### vnd hvote der ellenden vor den Crimhilde man
###### 1834 | ### Des nahtes wol emmitten ine weiz iz ê geschach ### daz Volker der chvene einen helm schinen sach ### verre vz einer vinster di Criemhilde man ### di wolden an den gestn gerne shaden han getan
###### 1835 | ### Do sprach der videlære frivnt Hagene ### vns zimt disiv sorge ensamt ce tragene ### ich sihe gewaffente livte bi dem hvse sten ### als ich mich versinne ich wæne si wellent vns besten
| ### So swiget sprach do Hagene lat se vns her naher baz ### ê si vnser werden innen so wirt hi helmvaz ### verrvchet mit den swerten von vnser zweier hant ### si werdent Criemhilde hin wider vebele gesant
###### 1837 | ### Ein der Hivnen rechen vil schiere daz gesach ### daz div tver was behevtet wi balde er do sprach ### des wir da heten willen ian mages niht ergan ### ich sihe den videlære an der schiltwahte stan
###### 1838 | ### Der treit vf sinem hovbete einen helm glanz ### lvter vnd herte starch [383a] vnde ganz ### ovch <lovhtent> im di ringe sam daz fiwer tvt ### bi im stet ovch Hagene des sint di geste wol behvt
| ### Zehant si cherten widere do Volker daz ersach ### wider sinen gesellen er zornechlichen sprach ### nv lat mich zv den recken vor dem hvse gan ### ich wil vragen mære der vrovn Criemhilde man
###### 1840 | ### Nein dvrch mine liebe sprach do Hagene ### chomt ir von dem hvse di snellen degene ### bringent ivch mit swerten vil lihte in soelhe not ### daz ich iv mvese helfen vnd wær iz aller miner mage tot
###### 1841 | ### So wir danne beide chomen in den strit ### ir zwene oder viere in einer chvrcen zit ### sprvengen zv dem hvse vnde tæten vns div leit ### an den slaffenden recken div nimmer werden verchleit
| ### Do sprach aber Volker so lat daz geschehen ### daz wir si bringen innen daz ich si habe gesehen ### daz des iht haben lovgen di Criemhilde man ### daz si vngetriweliche vil gerne heten getan
###### 1843 | ### Zehant do rief in Volker hin engegene ### wi get ir svs gewaffent ir snellen degene ### welt ir shachen riten ir Criemhilde man ### dar svlt ir mich ce helfe vnde mine hergesellen han
###### 1844 | ### Des antwrte im niemen zornech was sin mvt ### pfi ir zagen boese sprach der helt gvt ### wolt ir slaffende vns enmordet han ### daz ist so gvten helden noch vil selten her getan
| ### Do wart der chveneginne vil rehte geseit ### daz ir boten niht <erworben> von schvlden was ir leit ### do fvgete si ez anders vil grimmech was ir mvt ### des mvosen sit verderben di helde chvne vnde gvt

<<< Übersicht <<< vorige Seite nächste Seite >>>